@@ -6,16 +6,18 @@ use warnings;
 use Device::Chip::Ex::GPIOTickitUI;
 
 use Device::Chip::Adapter;
-use Device::Chip::PCF8574;
 
 use Getopt::Long;
 
 GetOptions(
    'adapter|A=s' => \( my $ADAPTER = "BusPirate" ),
+   'chip|C=s'    => \( my $CHIP = "PCF8574" ),
    'mount|M=s'   => \( my $MOUNTPARAMS ),
 ) or exit 1;
 
-my $chip = Device::Chip::PCF8574->new;
+require "Device/Chip/$CHIP.pm";
+my $chip = ${\"Device::Chip::$CHIP"}->new;
+
 $chip->mount_from_paramstr(
    Device::Chip::Adapter->new_from_description( $ADAPTER ), $MOUNTPARAMS,
 )->get;
